# https://codeload.github.com/fail2ban/fail2ban/tar.gz/refs/tags/1.0.2
Name:		          fail2ban
Version:	        1.0.2
Release:	        %mkrel 1
Summary:	        Ban hosts that cause multiple authentication errors

License:	        GPLv2+
Group:		        System/Configuration/Networking
URL:		          http://www.fail2ban.org/
Source0:	        %{name}-%{version}.tar.gz
Source1:	        %{name}-initscript
Source2:	        paths-pclinuxos.conf
Source3:            %{name}.logrotate

Patch0:  %{name}-python311.patch
Patch1:  %{name}-0.10.0-pclinuxos-paths.patch
Patch2:  %{name}-1.0.2-allowipv6-auto.patch

#squidf: richer filter for nginx
Patch20:    %{name}-1.0.1-enriched-nginx-botsearch.patch
#squidf: no need to inform back the attacker about the failed request
Patch21:    %{name}-1.0.1-no-attacker-feedback-shorewall.patch
#squidf: server ip address can appear clearly on abuseipd website, in some cases
Patch22:    %{name}-1.0.1-too-much-info-abuseipd.patch

BuildArch:        noarch
BuildRequires:    python3-coverage
BuildRequires:	  python3-devel
BuildRequires:    python3-setuptools
Requires(post):   rpm-helper
Requires(preun):  rpm-helper
Requires:	      iptables >= 1.3.5
Requires:	      python3 >= %{python3_version}
Requires:	      tcp_wrappers >= 7.6-29

%description
Fail2Ban scans log files like /var/log/auth.log and bans IP addresses having
too many failed login attempts. It does this by updating system firewall
rules to reject new connections from those IP addresses, for a configurable
amount of time. Fail2Ban comes out-of-the-box ready to read many standard
log files, such as those for sshd and Apache, and is easy to configure
to read any log file you choose, for any error you choose.

%package          tests
Summary:	        Fail2Ban testcases
Group:            System/Configuration/Networking
Requires:	        %{name} = %{version}-%{release}

%description      tests
Package provides testscases and scripts for %{name}.

%prep
%setup -q
%apply_patches

%build
./fail2ban-2to3
find -type f -iname \*.bak -delete
for i in fail2ban/server/action.py \
fail2ban/server/asyncserver.py \
fail2ban/helpers.py \
fail2ban/server/observer.py \
fail2ban/server/ticket.py \
fail2ban/server/transmitter.py \
fail2ban/server/utils.py; do
sed -i '/import collections/a collections.Callable = collections.abc.Callable' $i
done
%py3_build
%install

%py3_install
%py_byte_compile %{__python3} %{buildroot}%{python3_sitelib}
%__install -Dm644 files/bash-completion %{buildroot}%{_datadir}/bash-completion/completions/%{name}
%__install -d %{buildroot}%{_mandir}/man{1,5}
%__install -m644 man/*.1 %{buildroot}%{_mandir}/man1/
%__install -m644 man/jail.conf.5 %{buildroot}%{_mandir}/man5/
%__install -Dm744 %{S:1} %{buildroot}%{_initrddir}/%{name}
%__install -m644 %{S:2} %{buildroot}%{_sysconfdir}/%{name}/paths-pclinuxos.conf
%__install -dm755 %{buildroot}%{_var}/lib/%{name}
%__install -dm755 %{buildroot}%{_var}/run/%{name}
%__install -dm755 %{buildroot}%{_sysconfdir}/logrotate.d
%__install -pm 644 %{SOURCE3}  %{buildroot}%{_sysconfdir}/logrotate.d/%{name}
%__rm -rf %{buildroot}%{_docdir}/%{name}

# Remove non-Linux actions
rm %{buildroot}%{_sysconfdir}/%{name}/action.d/*ipfw.conf
rm %{buildroot}%{_sysconfdir}/%{name}/action.d/{ipfilter,pf,ufw}.conf
rm %{buildroot}%{_sysconfdir}/%{name}/action.d/osx-*.conf

%check
%__cp -vf %{S:2} config/
export LANG=en_US.UTF-8
./fail2ban-testcases-all-python3 -f --no-network

%pre
if [ $1 -gt 1 ] ; then
%__service %{name} stop &>/dev/null
fi
exit 0

%post
%_post_service %{name}
%__service %{name} start
exit 0

%preun
%_preun_service %{name}
exit 0

%files
%defattr(-,root,root)
%doc ChangeLog FILTERS README.md doc/run-rootless.txt
%dir %{_sysconfdir}/%{name}
%config(noreplace) %{_sysconfdir}/%{name}/*.conf
%dir %{_sysconfdir}/%{name}/action.d/
%config(noreplace) %{_sysconfdir}/%{name}/action.d/*.conf
%config %{_sysconfdir}/logrotate.d/%{name}
%{_sysconfdir}/%{name}/action.d/*.py
%dir %{_sysconfdir}/%{name}/filter.d/
%dir %{_sysconfdir}/%{name}/filter.d/ignorecommands
%config(noreplace) %{_sysconfdir}/%{name}/filter.d/*.conf
%{_sysconfdir}/%{name}/filter.d/ignorecommands/apache-fakegooglebot
%dir %{_sysconfdir}/%{name}/jail.d
%attr(744,root,root) %{_initrddir}/%{name}
%{_bindir}/%{name}-*
%{python3_sitelib}/%{name}
%{python3_sitelib}/%{name}-%{version}-py%{python3_version}.egg-info
%{_datadir}/bash-completion/completions/%{name}
%{_mandir}/man1/%{name}*.bz2
%{_mandir}/man5/jail.conf.5.bz2
%dir %{_var}/lib/%{name}
%dir %{_var}/run/%{name}
%exclude %{_bindir}/%{name}-testcases
%exclude %{python3_sitelib}/%{name}/tests
%exclude %{_mandir}/man1/%{name}-testcases.1.bz2

%files tests
%defattr(-,root,root)
%doc DEVELOP
%{_bindir}/%{name}-testcases
%{python3_sitelib}/%{name}/tests
%{_mandir}/man1/%{name}-testcases.1.bz2

%changelog
* Mon May 01 2023 yodelu 1.0.2-1pclos2023
- version update

* Fri Aug 05 2022 yodelu 0.11.2-2pclos2022
- fix build for python 3.10

* Thu Apr 15 2021 yodelu 0.11.2-1pclos2021
- update

* Wed Apr 25 2018 marcin82 <fixxer1982 at gmail.com> 0.10.3.1-1pclos2018
- update, switched to python3
- temporarily added %%pre scriplet and 2nd line of %%post for smoothly
  transition to python3

* Wed Feb 07 2018 marcin82 <fixxer1982 at gmail.com> 0.10.2-1pclos2018
- update
- enabled bash completion and byte compiling

* Tue Nov 14 2017 marcin82 <m82 at op.pl> 0.10.1-1pclos2017
- update

* Fri Aug 18 2017 marcin82 <marcin82 at vp.pl> 0.10.0-1pclos2017
- update, reorganized %%files section
- splitted out %{name}-tests package
- added %%preun scriptlet to clean python cache on package uninstall
- added %%patch1 - included paths-pclinuxos.conf
- added jail.conf.5.bz2 manpage

* Sat Jun 10 2017 marcin82 <marcin82 at vp.pl> 0.9.7-1pclos2017
- update
- changes in init service file - init-info section

* Fri Mar 11 2016 bb <bb> 0.9.4-1pclos2016
- update

* Fri Nov 27 2015 gseaman <galen.seaman at comcast.net> 0.9.3-1gseaman2015
- 0.9.3

* Tue Jan 28 2014 bb <bb> 0.8.12-1pclos2014
- update
